@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::NIGELM;
 use strict;
 use warnings;
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 use Moose 1.00;
@@ -177,6 +177,13 @@ has disable_pod_coverage_tests => (
 );
 
 
+has disable_pod_spelling_tests => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
+
 has disable_trailing_whitespace_tests => (
     is      => 'ro',
     isa     => Bool,
@@ -461,6 +468,13 @@ override BUILDARGS => sub {
     return { %{ $args->{payload} }, %{$args} };
 };
 
+
+has prune_directories => (
+    is      => 'ro',
+    isa     => 'ArrayRef[Str]',
+    default => sub { return [ 'local', 'vendor' ] },    # skip carton dirs
+);
+
 method configure () {
 
     # Build a list of all the plugins we want...
@@ -482,13 +496,13 @@ method configure () {
         ['Git::CheckFor::MergeConflicts'],
 
         # -- fetch & generate files
-        [ GatherDir            => {} ],
-        [ 'Test::Compile'      => { fake_home => $self->fake_home } ],
+        [ GatherDir            => { prune_directory => $self->prune_directories } ],
+        [ 'Test::Compile'      => { fake_home       => $self->fake_home } ],
         [ 'Test::Perl::Critic' => {} ],
         [ MetaTests            => {} ],
         ( $self->disable_pod_coverage_tests ? () : [ PodCoverageTests => {} ] ),
-        [ PodSyntaxTests      => {} ],
-        [ 'Test::PodSpelling' => {} ],
+        [ PodSyntaxTests => {} ],
+        ( $self->disable_pod_spelling_tests ? () : [ 'Test::PodSpelling' => {} ] ),
         (    # Disabling pod coverage scores you a fail on Kwalitee too!
             $self->disable_pod_coverage_tests ? () : [ KwaliteeTests => {} ]
         ),
@@ -612,7 +626,7 @@ Dist::Zilla::PluginBundle::NIGELM - Build your distributions like I do
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -760,6 +774,11 @@ distribution name.
 If set, disables the Pod Coverage Release Tests
 L<Dist::Zilla::Plugin::PodCoverageTests>. Defaults to unset (tests enabled).
 
+=head3 disable_pod_spelling_tests
+
+If set, disables the Pod Spelling Release Tests
+L<Dist::Zilla::Plugin::Test::PodSpelling>. Defaults to unset (tests enabled).
+
 =head3 disable_trailing_whitespace_tests
 
 If set, disables the Trailing Whitespace Release Tests
@@ -850,6 +869,11 @@ a release is attempted from another branch the release will fail.
 
 The Change Log file name.  Defaults to C<Changes>.
 
+=head3 prune_directories
+
+Directories to ignore - currently defaults to C<local> and C<vendor> (the
+directories used by carton to store required modules).
+
 =head1 BUGS
 
 It appears this module, in particular the C<ReadmeAnyFromPod> plugin, exposes a
@@ -881,7 +905,7 @@ Nigel Metheringham <nigelm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nigel Metheringham.
+This software is copyright (c) 2016 by Nigel Metheringham.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
